@@ -10,7 +10,7 @@ use strict;
 use warnings;
 use vars '%Config', '$VERSION';
 
-$VERSION = "5.026001";
+$VERSION = "5.026002";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,11 +56,11 @@ sub import {
     return;
 }
 
-die "$0: Perl lib version (5.26.1) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.26.2) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.26.1
-    or die sprintf "%s: Perl lib version (5.26.1) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.26.2
+    or die sprintf "%s: Perl lib version (5.26.2) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -85,7 +85,7 @@ sub AUTOLOAD {
 # tie returns the object, so the value returned to require will be true.
 tie %Config, 'Config', {
     archlibexp => '/usr/lib/perl5/5.26/core_perl',
-    archname => 'armv7l-linux-thread-multi',
+    archname => 'armv5tel-linux-thread-multi',
     cc => 'cc',
     d_readlink => 'define',
     d_symlink => 'define',
@@ -96,9 +96,9 @@ tie %Config, 'Config', {
     inc_version_list => ' ',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/usr/local/lib /usr/lib/gcc/armv5tel-unknown-linux-gnueabi/7.2.1/include-fixed /usr/lib /lib',
+    libpth => '/usr/local/lib /usr/lib/gcc/armv5tel-unknown-linux-gnueabi/7.3.1/include-fixed /usr/lib /lib',
     osname => 'linux',
-    osvers => '4.14.13-1-arch',
+    osvers => '4.14.29-1-arch',
     path_sep => ':',
     privlibexp => '/usr/share/perl5/core_perl',
     scriptdir => '/usr/bin/core_perl',
@@ -107,5 +107,5 @@ tie %Config, 'Config', {
     so => 'so',
     useithreads => 'define',
     usevendorprefix => 'define',
-    version => '5.26.1',
+    version => '5.26.2',
 };
